@@ -419,6 +419,41 @@ sub cmd_list {
     }
 }
 
+sub cmd_diff {
+    my $self = shift;
+
+    my $snapshot_path = $self->cpanfile->snapshot_path->relative;
+
+    # Don't check if .git exists, and let git(2) handle the error
+
+    if ($ENV{PERL_CARMEL_USE_DIFFTOOL}) {
+        my $cmd = 'carmel difftool';
+        $cmd .= ' -v' if $self->verbose;
+
+        system 'git', 'difftool', '--no-prompt',
+          '--extcmd', $cmd, $snapshot_path;
+    } else {
+        require Carmel::Difftool;
+
+        my $content = `git show HEAD:$snapshot_path`
+          or die "Can't retrieve snapshot content for $snapshot_path\n";
+        my $path = Path::Tiny->tempfile;
+        $path->spew($content);
+
+        my $diff = Carmel::Difftool->new;
+        $diff->diff($path, $snapshot_path);
+    }
+}
+
+sub cmd_difftool {
+    my($self, @args) = @_;
+
+    require Carmel::Difftool;
+
+    my $diff = Carmel::Difftool->new;
+    $diff->diff(@args);
+}
+
 sub resolve {
     my($self, $cb) = @_;
     $self->resolver(found => $cb)->resolve;
